pub enum TestName {
NAAT {
name: String,
},
RAT {
device_id: String,
},
}Expand description
Identifies the recognized test types
Variants
NAAT
A Nucleic Acid Amplification Test, with the name of the specific test
RAT
A Rapid Antigen Test, with a string identifying the device from the JRC database